==> lalsimulation-1.6.0.tar.xz: lalsimulation-1.6.0/src/LALSimulationVCSInfoHeader.h <==
/*
 * LALSimulationVCSInfo.h - LALSimulation VCS Information Header
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 * Copyright (C) 2009-2013 Adam Mercer
 * Copyright (C) 2014 Karl Wette
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALSIMULATIONVCSINFOHEADER_H
#define _LALSIMULATIONVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <lal/LALSimulationVCSInfo.h>
#include <lal/LALSimulationConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information defines */
#define LALSIMULATION_NAME "LALSimulation"
#define LALSIMULATION_VCS_ID "f38b2d06b8b64e8a616232c9d79439fdeca0d412"
#define LALSIMULATION_VCS_DATE "2016-06-26 21:26:32 +0000"
#define LALSIMULATION_VCS_BRANCH "None"
#define LALSIMULATION_VCS_TAG "lalsimulation-v1.6.0"
#define LALSIMULATION_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALSIMULATION_VCS_COMMITTER "Adam Mercer <ramercer@gmail.com>"
#define LALSIMULATION_VCS_STATUS "CLEAN: All modifications committed"

/* Identable VCS information defines */
#define LALSIMULATION_VCS_IDENT_ID "$" "LALSimulationId: f38b2d06b8b64e8a616232c9d79439fdeca0d412 " "$"
#define LALSIMULATION_VCS_IDENT_DATE "$" "LALSimulationDate: 2016-06-26 21:26:32 +0000 " "$"
#define LALSIMULATION_VCS_IDENT_BRANCH "$" "LALSimulationBranch: None " "$"
#define LALSIMULATION_VCS_IDENT_TAG "$" "LALSimulationTag: lalsimulation-v1.6.0 " "$"
#define LALSIMULATION_VCS_IDENT_AUTHOR "$" "LALSimulationAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LALSIMULATION_VCS_IDENT_COMMITTER "$" "LALSimulationCommitter: Adam Mercer <ramercer@gmail.com> " "$"
#define LALSIMULATION_VCS_IDENT_STATUS "$" "LALSimulationStatus: CLEAN: All modifications committed " "$"

/* Header VCS information structure */
static const LALVCSInfo lalSimulationVCSInfoHeader = { \
  LALSIMULATION_NAME, \
  LALSIMULATION_VERSION, \
  LALSIMULATION_VCS_ID, \
  LALSIMULATION_VCS_DATE, \
  LALSIMULATION_VCS_BRANCH, \
  LALSIMULATION_VCS_TAG, \
  LALSIMULATION_VCS_AUTHOR, \
  LALSIMULATION_VCS_COMMITTER, \
  LALSIMULATION_VCS_STATUS \
};

#ifdef __cplusplus
}
#endif

#endif /* _LALSIMULATIONVCSINFOHEADER_H */

/** \endcond */

/*
 * vim: tw=0 ts=2 et
 */

==> lalsimulation-1.6.1.tar.xz: lalsimulation-1.6.1/src/LALSimulationVCSInfoHeader.h <==
/*
 * LALSimulationVCSInfo.h - LALSimulation VCS Information Header
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 * Copyright (C) 2009-2013 Adam Mercer
 * Copyright (C) 2014 Karl Wette
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALSIMULATIONVCSINFOHEADER_H
#define _LALSIMULATIONVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <lal/LALSimulationVCSInfo.h>
#include <lal/LALSimulationConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information defines */
#define LALSIMULATION_NAME "LALSimulation"
#define LALSIMULATION_VCS_ID "2caa475aa99f81c133c0d5047f4ad6f41d3f8064"
#define LALSIMULATION_VCS_DATE "2016-10-10 17:31:35 +0000"
#define LALSIMULATION_VCS_BRANCH "None"
#define LALSIMULATION_VCS_TAG "lalsimulation-v1.6.1"
#define LALSIMULATION_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALSIMULATION_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
#define LALSIMULATION_VCS_STATUS "CLEAN: All modifications committed"

/* Identable VCS information defines */
#define LALSIMULATION_VCS_IDENT_ID "$" "LALSimulationId: 2caa475aa99f81c133c0d5047f4ad6f41d3f8064 " "$"
#define LALSIMULATION_VCS_IDENT_DATE "$" "LALSimulationDate: 2016-10-10 17:31:35 +0000 " "$"
#define LALSIMULATION_VCS_IDENT_BRANCH "$" "LALSimulationBranch: None " "$"
#define LALSIMULATION_VCS_IDENT_TAG "$" "LALSimulationTag: lalsimulation-v1.6.1 " "$"
#define LALSIMULATION_VCS_IDENT_AUTHOR "$" "LALSimulationAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LALSIMULATION_VCS_IDENT_COMMITTER "$" "LALSimulationCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LALSIMULATION_VCS_IDENT_STATUS "$" "LALSimulationStatus: CLEAN: All modifications committed " "$"

/* Header VCS information structure */
static const LALVCSInfo lalSimulationVCSInfoHeader = { \
  LALSIMULATION_NAME, \
  LALSIMULATION_VERSION, \
  LALSIMULATION_VCS_ID, \
  LALSIMULATION_VCS_DATE, \
  LALSIMULATION_VCS_BRANCH, \
  LALSIMULATION_VCS_TAG, \
  LALSIMULATION_VCS_AUTHOR, \
  LALSIMULATION_VCS_COMMITTER, \
  LALSIMULATION_VCS_STATUS \
};

#ifdef __cplusplus
}
#endif

#endif /* _LALSIMULATIONVCSINFOHEADER_H */

/** \endcond */

/*
 * vim: tw=0 ts=2 et
 */
